==> react-7.4.1.tgz: package/es/AlertCall/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import DeviceListCall from "./DeviceListCall";
import { AlertContainer, Avatar, Button, Icon } from "./..";
/**
 * @category communication
 * @component alert-call
 * @variations collab-ui-react
 */

var AlertCall = function AlertCall(props) {
  var avatar = props.avatar,
      caller = props.caller,
      deviceListHeader = props.deviceListHeader,
      devices = props.devices,
      onAnswerVideo = props.onAnswerVideo,
      onAnswerVoice = props.onAnswerVoice,
      onReject = props.onReject,
      show = props.show,
      title = props.title;

  var getAvatar = function getAvatar() {
    if (avatar) {
      return avatar;
    } else {
      switch (caller.type) {
        case 'number':
          return React.createElement(Avatar, {
            title: "#",
            alt: caller.title,
            size: "xlarge"
          });

        case 'device':
          return React.createElement(Avatar, {
            icon: React.createElement(Icon, {
              name: "spark-board_32"
            }),
            alt: caller.title,
            size: "xlarge"
          });

        default:
          return React.createElement(Avatar, {
            title: caller.title,
            alt: caller.title,
            size: "xlarge"
          });
      }
    }
  };

  var getDeviceList = function getDeviceList() {
    return devices.length > 0 && React.createElement(DeviceListCall, {
      devices: devices,
      header: deviceListHeader
    });
  };

  return show && React.createElement(AlertContainer, {
    className: "cui-alert--call"
  }, React.createElement("div", {
    className: "cui-alert__title"
  }, title), React.createElement("div", {
    className: "cui-alert__caller"
  }, getAvatar(), React.createElement("div", {
    className: "cui-alert__caller-title"
  }, caller.title), React.createElement("div", {
    className: "cui-alert__caller-subtitle"
  }, caller.alt)), getDeviceList(), React.createElement("div", {
    className: "cui-alert--call--buttons"
  }, React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "camera_24"
    }),
    onClick: onAnswerVideo,
    ariaLabel: "answer call with voice and video",
    color: "green",
    circle: true,
    large: true
  }), onAnswerVoice && React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "handset_24"
    }),
    onClick: onAnswerVoice,
    ariaLabel: "answer call with voice only",
    color: "green",
    circle: true,
    large: true
  }), React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "cancel_24"
    }),
    onClick: onReject,
    ariaLabel: "reject call",
    color: "red",
    circle: true,
    large: true
  })));
};

AlertCall.defaultProps = {
  avatar: null,
  caller: null,
  title: '',
  onRejectCall: null,
  onVoiceCall: null,
  onVideoCall: null,
  deviceListHeader: 'Device selection',
  devices: []
};
AlertCall.propTypes = {
  /**
   * required caller object
   */
  caller: PropTypes.shape({
    title: PropTypes.string.isRequired,
    alt: PropTypes.string,
    src: PropTypes.string,
    type: PropTypes.oneOf(['', 'number', 'device'])
  }).isRequired,

  /**
   * callback function invoked when the reject button is clicked.
   */
  onRejectCall: PropTypes.func,

  /**
   * callback function invoked when the handset button is clicked.
   */
  onAnswerVoice: PropTypes.func,

  /**
   * callback function invoked when the video button is clicked.
   */
  onAnswerVideo: PropTypes.func,

  /**
   * required show/hide AlertCall.
   */
  show: PropTypes.bool.isRequired,

  /**
   * optional title of AlertCall
   */
  title: PropTypes.string,

  /**
   * optional header string for device selection list
   */
  deviceListHeader: PropTypes.string,

  /**
   * optional list of devices to answer call with.
   */
  devices: PropTypes.array,

  /**
   * optional avatar prop
   */
  avatar: PropTypes.node
};
AlertCall.displayName = 'AlertCall';
export default AlertCall;
/**
* @name Call
* @description Control the avatar type by passing in the type of caller to the caller.type prop.
*
* @category communication
* @component alert
* @section call
*
* @js

import {
  Button,
  AlertCall
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showAlert: false,
    caller: {title: 'Jefe Guadelupe', alt: '+ 1 972-555-1212'}
  }

  render() {
    return (
      <section>
        <div>
          <div className='row'>
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({ showAlert: true, caller: {title: 'Jefe Guadelupe', alt: '+ 1 972-555-1212'} })}
              children='Person Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({
                showAlert: true,
                caller: {title: 'SJC21-Babelfish', alt: '+ 1 408-555-1212', type: 'device'},
                devices: []
              })}
              children='Device Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({
                showAlert: true,
                caller: {title: '+ 1 408-555-1212', type: 'number'},
                devices: []
              })}
              children='Number Only Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({
                showAlert: true,
                caller: {title: '+ 1 408-555-1212', type: 'number'},
                devices: [
                  {name: 'SJC21-Babelfish', value: '1010101', type: 'device'},
                  {name: 'Use my computer', value: '2020202'}
                ] })}
              children='Caller with Device List'
              color='primary'
              size='large'
            />
          </div>
          <br />
          <AlertCall
            title='Incoming call'
            caller={this.state.caller}
            devices={this.state.devices}
            show={this.state.showAlert}
            onReject={() => this.setState({ showAlert: false})}
            onAnswerVoice={() => this.setState({ showAlert: false})}
            onAnswerVideo={() => this.setState({ showAlert: false})}
          />
        </div>
      </section>
    );
  }
}

**/

==> react-7.5.0.tgz: package/es/AlertCall/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import DeviceListCall from "./DeviceListCall";
import { Avatar, Button, Icon } from "./..";
/**
 * @category communication
 * @component alert-call
 * @variations collab-ui-react
 */

var AlertCall = function AlertCall(props) {
  var avatar = props.avatar,
      caller = props.caller,
      deviceListHeader = props.deviceListHeader,
      devices = props.devices,
      onAnswerVideo = props.onAnswerVideo,
      onAnswerVoice = props.onAnswerVoice,
      onDeviceSelect = props.onDeviceSelect,
      onReject = props.onReject,
      show = props.show,
      title = props.title;

  var getAvatar = function getAvatar() {
    if (avatar) {
      return avatar;
    } else {
      switch (caller.type) {
        case 'number':
          return React.createElement(Avatar, {
            title: "#",
            alt: caller.title,
            size: "xlarge"
          });

        case 'device':
          return React.createElement(Avatar, {
            icon: React.createElement(Icon, {
              name: "spark-board_32"
            }),
            alt: caller.title,
            size: "xlarge"
          });

        default:
          return React.createElement(Avatar, {
            title: caller.title,
            alt: caller.title,
            size: "xlarge"
          });
      }
    }
  };

  var getDeviceList = function getDeviceList() {
    return devices.length > 0 && React.createElement(DeviceListCall, {
      devices: devices,
      header: deviceListHeader,
      onSelect: onDeviceSelect
    });
  };

  return show && React.createElement("div", {
    className: "cui-alert cui-alert--call"
  }, React.createElement("div", {
    className: "cui-alert__title"
  }, title), React.createElement("div", {
    className: "cui-alert__caller"
  }, getAvatar(), React.createElement("div", {
    className: "cui-alert__caller-title"
  }, caller.title), React.createElement("div", {
    className: "cui-alert__caller-subtitle"
  }, caller.alt)), getDeviceList(), React.createElement("div", {
    className: "cui-alert--call--buttons"
  }, React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "camera_24"
    }),
    onClick: onAnswerVideo,
    ariaLabel: "answer call with voice and video",
    color: "green",
    circle: true,
    large: true
  }), onAnswerVoice && React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "handset_24"
    }),
    onClick: onAnswerVoice,
    ariaLabel: "answer call with voice only",
    color: "green",
    circle: true,
    large: true
  }), React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "cancel_24"
    }),
    onClick: onReject,
    ariaLabel: "reject call",
    color: "red",
    circle: true,
    large: true
  })));
};

AlertCall.defaultProps = {
  avatar: null,
  caller: null,
  title: '',
  onRejectCall: null,
  onVoiceCall: null,
  onVideoCall: null,
  deviceListHeader: 'Device selection',
  devices: [],
  onDeviceSelect: null
};
AlertCall.propTypes = {
  /**
   * required caller object
   */
  caller: PropTypes.shape({
    title: PropTypes.string.isRequired,
    alt: PropTypes.string,
    src: PropTypes.string,
    type: PropTypes.oneOf(['', 'number', 'device'])
  }).isRequired,

  /**
   * callback function invoked when the reject button is clicked.
   */
  onRejectCall: PropTypes.func,

  /**
   * callback function invoked when the handset button is clicked.
   */
  onAnswerVoice: PropTypes.func,

  /**
   * callback function invoked when the video button is clicked.
   */
  onAnswerVideo: PropTypes.func,

  /**
   * required show/hide AlertCall.
   */
  show: PropTypes.bool.isRequired,

  /**
   * optional title of AlertCall
   */
  title: PropTypes.string,

  /**
   * optional header string for device selection list
   */
  deviceListHeader: PropTypes.string,

  /**
   * optional list of devices to answer call with.
   */
  devices: PropTypes.array,

  /**
   * optional avatar prop
   */
  avatar: PropTypes.node,

  /**
   * optional callback function when device is selected
   */
  onDeviceSelect: PropTypes.func
};
AlertCall.displayName = 'AlertCall';
export default AlertCall;
/**
* @name Call
* @description Control the avatar type by passing in the type of caller to the caller.type prop.  There can only be 2 Call Alerts active at one time.
*
* @category communication
* @component alert
* @section call
*
* @js

import {
  Button,
  AlertCallContainer
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showAlert: false,
    caller: {title: 'Jefe Guadelupe', alt: '+ 1 972-555-1212'},
    devices: [
      {name: 'SJC21-Babelfish', value: '1010101', type: 'device'},
      {name: 'Use my computer', value: '2020202'}
    ]
  }

  render() {
    let alertCallContainer;
    return (
      <section>
        <div>
          <div className='row'>
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertCallContainer.callAlert(
                'IncomingCall',
                this.state.caller,
                undefined,
                undefined,
                () => console.log('onReject1'),
                () => console.log('onAnswerVoice1'),
                () => console.log('onAnswerVideo1'),
              )}
              children='Person Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertCallContainer.callAlert(
                'IncomingCall',
                {title: 'SJC21-Babelfish', alt: '+ 1 408-555-1212', type: 'device'},
                undefined,
                undefined,
                () => console.log('onReject2'),
                () => console.log('onAnswerVoice2'),
                () => console.log('onAnswerVideo2'),
              )}
              children='Device Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertCallContainer.callAlert(
                'IncomingCall',
                {title: '+ 1 408-555-1212', type: 'number'},
                undefined,
                undefined,
                () => console.log('onReject3'),
                () => console.log('onAnswerVoice3'),
                () => console.log('onAnswerVideo3'),
              )}
              children='Number Only Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertCallContainer.callAlert(
                'IncomingCall',
                {title: '+ 1 408-555-1212', type: 'number'},
                undefined,
                this.state.devices,
                () => console.log('onReject4'),
                () => console.log('onAnswerVoice4'),
                () => console.log('onAnswerVideo4'),
              )}
              children='Caller with Device List'
              color='primary'
              size='large'
            />
          </div>
          <br />
          <AlertCallContainer
            ref={ref => alertCallContainer = ref}
          />
        </div>
      </section>
    );
  }
}

**/
